#ifndef TPC_PASA_H
#define TPC_PASA_H
#include "TF2.h"
//-----------------------------------------------------------------------------
// ==========
// class Pasa 
// ==========
// (Description)
//    Class to describe a PASA + FADC.
// (Provides)
//    TPC::Pasa               : PASA object
// (Update Record)
//    2015/07/10  K.Fujii     Original version.
//-----------------------------------------------------------------------------
namespace TPC {
class Pasa : public TF2 {
public:
    Pasa(double tpk   = 120.,   // peaking time   [ns] 
         int    n     =   3 ,   // shaper order
         double w     =  40.,   // time bin width [ns]
         double noise =   1.,   // noise          [adc]
         double norm  = 0.014); // conversion factor: #e's to adc

    inline double GetTpeak() const { return GetParameter(0); }
    inline int    GetN    () const { return GetParameter(1); }
    inline double GetW    () const { return GetParameter(2); }
    inline double GetNoise() const { return GetParameter(3); }
    inline double GetNorm () const { return GetParameter(4); }

    double Charge    (const double *x, const double *p);
    double Ft        (double t, int a);

    double Pulse     (const double *x, const double *p);
    //double Pulse     (double *x, double *p);
    double Pulse     (double t, double tau, int n) const;

private:
    double Area      (double a, double b, double tau, int n) const;

    ClassDef(Pasa, 1)   // Pulse shape class
};
}
#endif
