#include <TSystem.h>
// Usage:
//    root -l
//    [0] .L PlotPhyDep.C
//    [1] PlotPhyDep("250","sgx.dat")->Draw("apc");
//

double Fun(const double *xv, const double *pv)
{
  double sg2 = pv[0]*pv[0] + (pv[2]*pv[2]/(12.*pv[1]/cos(xv[0]))) *tan(xv[0])*tan(xv[0]);
  return sqrt(sg2);
}

TGraphErrors *PlotPhiDep(const char *dlen = "250", const char *fname = "sg.dat", double L = 5.36)
{
  stringstream cmds;
  cmds  << "sort -k 1 " << fname << " | sed -n -e '/^0\\.[0-9]\\{1,\\} [0-9.]\\{1,\\} *" 
                        << dlen << " .*/p'"  << ends; 
  cerr << cmds.str() << endl;

  TString list = gSystem->GetFromPipe(cmds.str().data());
#if 0
  cerr << list << endl;
#endif

  stringstream cmds2;
  cmds2  << "sort -k 1 " << fname << " | sed -n -e '/^0\\.[0-9]\\{1,\\} [0-9.]\\{1,\\} *" 
                         << dlen << " .*/p'" 
			 << " | sed -e '/^0.00\\.*/d'"
			 << " | sort -r | sed -e 's;^\\(\\.*\\);-\\1;' "  << ends; 
  cerr << cmds2.str() << endl;

  TString list2 = gSystem->GetFromPipe(cmds2.str().data());
#if  0
  cerr << list2 << endl;
#endif

  list  = list2 + '\n' + list;
  cerr << list << endl;

  stringstream ins(list.Data());

  const int kNp = 100;
  double phi, theta, z, sgx, dsgx, sgz, dsgz;
  double  x[kNp], dx[kNp], y[kNp], dy[kNp];
  int np = 0;
  while ((ins >> phi >> theta >> z >> sgx >> dsgx >> sgz >> dsgz)) {
    x [np] = phi;
    dx[np] = 0.;
    y [np] = sgx;
    dy[np] = dsgx;
#if 1
    cerr << x[np] << " " << y[np] << " +/- " << dy[np] << endl;
#endif
    np++;
  }
  TGraphErrors *grp = new TGraphErrors(np,x,y,dx,dy);

  TF1 *funp = new TF1("fun",&Fun,-1.,1.,3);
  funp->SetParameter(0,0.1);
  funp->SetParameter(1,5.);
  funp->FixParameter(2,L);
  //grp->Fit(funp,"Q","",-40,40);
  grp->Fit(funp,"","",-1,1);
  grp->GetHistogram()->SetMinimum(0.);

  cerr << fname << endl
       << " Nheff(F) = " << funp->GetParameter(1) 
       << " +/- "        << funp->GetParError (1)
       << endl;

  return grp;

//--------------------------------------
// output Nhateff data
//--------------------------------------
#if 0
  ofstream fout("Nhateff.dat",ios::app);
  fout << setw(5) << setprecision(3) << setiosflags(ios::fixed) << phi << " "
       << setw(5) << setprecision(3) << setiosflags(ios::fixed) << dlen << " "
       << setw(8) << setprecision(6) << setiosflags(ios::fixed) << funp->GetParameter(1) << " "
       << setw(8) << setprecision(6) << setiosflags(ios::fixed) << funp->GetParError(1) 
       << endl;
#endif  

}
