#define USE_HIST
// script to plot pulse shapes at different z positions before and after 
// digitization. 
// You should run this in compile mode as:
//   $ root -l
//   [0] .L Pulse.C+
//   [1] Pulse();
//
#include "Pasa.h"
#ifndef USE_HIST
#include "TGraph.h"
#else
#include "TH1D.h"
#endif
#include "TLine.h"

using namespace std;

void Pulse(double toff = 0.)
{ 
  //--
  // Draw PASA output pulse for various peaking times.
  //--
  const double tpk0  = 120.; // peak time [ns]
  const int    n0    = 4;
  //const double w0    = 20.;  // time bin width [ns]
  //const double w0    = 40.;  // time bin width [ns]
  const double w0    = 50.;  // time bin width [ns]
  const double noise = 50.;  // noise counts
  const double norm  =  1.;
  TPC::Pasa pca(tpk0,n0,w0,noise);

  // Wrapper function class to work around a strange cling problem.
  class Func {
  public:
	  Func(TPC::Pasa *pcap) : _pcap(pcap) {}

	  double Evaluate(double *xv, double *pv) {
		  return _pcap->Pulse(xv,pv);
	  }
  private:
	  TPC::Pasa *_pcap;
  };

  Func fn(&pca);

  double xmin = -200.;
  double xmax = +500.;
  int    npar = 5;
  //TF1 *fp = new TF1("pca", &pca, &TPC::Pasa::Pulse, xmin, xmax, npar);
  TF1 *fp = new TF1("fn", &fn, &Func::Evaluate, xmin, xmax, npar);
  double ymin = 0.00;
  double ymax = 0.03;
  fp->SetMinimum(ymin);
  fp->SetMaximum(ymax);

  int tdat[] = { 30, 60, 120 };
  const int itMax = sizeof(tdat)/sizeof(tdat[0]);
  int nt     = 0;
  for (int it=0; it<itMax; it++) {
      int color = it;
      int tpk = tdat[it];
      fp->SetParameter(0,tpk);
      fp->SetParameter(1,pca.GetN());
      fp->SetParameter(4,norm);
      fp->SetLineColor(++color%5+1);
      if (!nt) fp->DrawCopy();
      else     fp->DrawCopy("same");
      nt++;

      pca.SetParameter(0,tpk);

      cerr << "toff=" << toff << endl;

      const int kNb = 20;
      double xdata[kNb];
      double ydata[kNb];
      for (int ib=0; ib<kNb; ib++) {
         int itb   = ib + toff/pca.GetW();
         xdata[ib] = ib*pca.GetW() - toff + (itb-ib)*pca.GetW();
	 ydata[ib] = pca(toff,itb)/pca.GetW();
	 cerr << "t=" << xdata[ib] << " f=" << ydata[ib] << endl;
      }
#ifdef USE_HIST
      TH1D *hp = new TH1D("h","",kNb,xdata[0]+0.5*pca.GetW(),xdata[kNb-1]+1.5*pca.GetW());
      for (int ib=0; ib<kNb; ib++) {
         hp->SetBinContent(ib,ydata[ib]); 
      }
      hp->SetLineColor(color%5+1);
      hp->Draw("same");
#else
      TGraph *gp = new TGraph(kNb,xdata,ydata);
      gp->SetLineColor(color%5+1);
      gp->Draw("same");
#endif

      double dsum = 0.;
      double tinf = 0.;
      for (int ib=0; ib<kNb-1; ib++) {
	 if (ydata[ib] > ydata[ib+1]) break;
	 double diff = ydata[ib+1] - ydata[ib];
	 tinf += diff*(xdata[ib]+pca.GetW()/2);
	 dsum += diff;
	 cerr << "ib=" << ib << " x=" << xdata[ib] << " tinf=" << tinf << " dsum=" << dsum << endl;
      }
      tinf /= dsum;
      cerr << "tinf=" << tinf << endl;

#if 0
      int marker   = 1;
      TMarker *pp = new TMarker(tinf, 0., marker);
      pp->SetMarkerSize(2);
      pp->Draw();
#else
      TLine *lp = new TLine(tinf, ymin, tinf, ymax);
      lp->SetLineColor(color%5+1);
      lp->SetLineStyle(2);
      lp->Draw("same");
#endif
  }
}
