// script to compare pulse shapes for different tpk and n values.
// You should run this in compile mode as:
//   $ root -l
//   [0] .L PulseComp.C+
//   [1] PulseComp();
//
#include "Pasa.h"
#include <sstream>

using namespace std;

void PulseComp()
{ 
    //--
    // Draw PASA output pulse for various peaking times.
    //--
    const vector<double> tpkv  = {30., 60., 120.}; // peaking time [ns]
    const vector<int>    nv    = {3, 4};           // shaper order
    const double         w0    = 50.;  // time bin width [ns]
    const double         noise = 50.;  // noise counts
    const double         norm  =  1.;  // normalization factor
  
    // Wrapper function class to work around a strange cling problem.
    class Func {
    public:
  	  Func(TPC::Pasa *pcap) : _pcap(pcap) {}
  
  	  double Evaluate(double *xv, double *pv) {
  		  return _pcap->Pulse(xv,pv);
  	  }
    private:
  	  TPC::Pasa *_pcap;
    };
  
    int nt = 0;
    for (auto n : nv) {
	cerr << "n = " << n << endl;
        for (auto tpk : tpkv) {
            TPC::Pasa pca(tpk,n,w0,noise,norm);
            Func fn(&pca);
            double xmin = -200.;
            double xmax = +500.;
            int    npar = 5;
            stringstream fname;
            fname << "fn" << nt << ends;
            auto   fp  = new TF1(fname.str().data(), &fn, &Func::Evaluate, xmin, xmax, npar);
            double ymin = 0.00;
            double ymax = 0.03;
            fp->SetParameter(0,tpk);
            fp->SetParameter(1,n);
            fp->SetParameter(4,norm);
            fp->SetMinimum(ymin);
            fp->SetMaximum(ymax);
            int color = nt/3;
            fp->SetLineColor(++color%5+1);
	    fp->SetLineStyle(nt<3?0:2);
            if (!nt) fp->DrawCopy();
            else     fp->DrawCopy("same");
            nt++;
        }
    }
}
