//////////////////
#define USER_TUPLE
//////////////////
#include "Track.h"
#include "Hit.h"
#include "GEM.h"
#include "Pasa.h"

#include "TSystem.h"
#include "TROOT.h"
#include "TMath.h"
#include "TFile.h"
#include "TRandom.h"
#include "TCanvas.h"
#include "TH1D.h"
#include "TNtupleD.h"

#include <fstream>
#include <sstream>
#include <iomanip>

using namespace std;

void Resol(double z0    = 0.0,   // drift distance [mm]
           double phi   = 0.0,   // track phi      [rad]
           double lam   = 0.0,   // track lambda   [rad]
	   int    nev   = 40000, // # events to generate
	   bool   isCOG = false)  // time calculation method
{ 
  //--
  // PASA
  //--
  const double tpk0  = 120.; // pekaing time   [ns] //catalog
  //const double tpk0  = 174.; // pekaing time   [ns] //(3.48*50ns / 19987 Module3row16)
  //const double tpk0  = 180.; // pekaing time   [ns] //
  //const double tpk0  = 160.; // pekaing time   [ns] //
  //const double tpk0  = 140.; // pekaing time   [ns] //
  //const double tpk0  = 130.; // pekaing time   [ns] //
  //const double tpk0  = 115.; // pekaing time   [ns] //
  //const double tpk0  = 134.; // pekaing time   [ns] //calculated
  //const double tpk0  = 147.; // pekaing time   [ns] //calculated
  //const double tpk0  = 156.; // pekaing time   [ns] //calculated
  //const double tpk0  = 167.; // pekaing time   [ns] //calculated
  const int    n0    = 3;    // shaper order //20210518 4->3
  //const double    n0    = 3.45;    // shaper order 
  //const double    n0    = 3.73;    // shaper order 
  //const double    n0    = 3.99;    // shaper order 
  const double w0    = 50.;  // time bin width [ns]
  //const double noise = 10.;  // noise count
  //const double noise = 5.;  // noise count
  //const double noise = 0.;  // noise count
  const double noise = 2.;  // noise count
//  const double noise = 1.;  // noise count //FIXME
//  const double noise = 0.5;  // noise count
//  const double noise = 0.1;  // noise count
  //const double norm = 0.014;  // conversion factor: #e's to ADC
  //const double norm = 0.0061;  // conversion factor: #e's to ADC //FIXME
  //const double norm = 0.008;  // conversion factor: #e's to ADC //FIXME
  //const double norm = 0.0085;  // conversion factor: #e's to ADC //FIXME
  //const double norm = 0.0088;  // conversion factor: #e's to ADC //FIXME
  const double norm = 0.0055;  // conversion factor: #e's to ADC //FIXME
  TPC::Pasa  pca(tpk0,n0,w0,noise,norm);

  TPC::Hit::Pulse::SetWithNoise(kTRUE);
//  TPC::Hit::Pulse::SetWithNoise(kFALSE);
//  TPC::Hit::Pulse::SetWithADCLimit(kTRUE);
  TPC::Hit::Pulse::SetWithADCLimit(kFALSE);
  cerr << "WithNoise = " << TPC::Hit::Pulse::GetWithNoise() << endl;
  cerr << "WithADCLimit = " << TPC::Hit::Pulse::GetWithADCLimit() << endl;

  //--
  // GEM
  //--
#if 1
//  double sgprf = 0.01; // sigma_PRF  [mm]
//  double sgprf = 0.22; // sigma_PRF  [mm]
//  double sgprf = 0.27; // sigma_PRF  [mm]
  double sgprf = 0.29; // sigma_PRF  [mm]
#else
  double sgprf = 0.22; // sigma_PRF  [mm]
#endif
  double wpad  = 1.15; // pad pitch  [mm]
//  double wpad  = 0.50; // pad pitch  [mm]
//  double wpad  = 2.0; // pad pitch  [mm]
  double lpad  = 5.36; // pad length [mm]
  double len   = 10.;  // seg length [mm]
  double vgap   = 50.;  //drift velocity in induction gap[um/ns]
  double igap   = 2.;  //[mm]
  double gain   = 2000.;  //average gas gain
  double theta   = 0.50;  // polya parameter
#if 0
    double nav   = 30.;  // <#primary ionizations>
           nav  *= 1.2;  // 5 GeV electron > MIP
#else
#if 1
  double nav   = 27.5;  // <#primary ionizations> [1/cm] for MIP as from HEED (T2K)
         nav  *= 1.38;  // 5 GeV electron > MIP
#else
  double nav   = 15.5;  // <#primary ionizations> [1/cm] for MIP
         nav  *= 1.38;  // 5 GeV electron > MIP
#endif
#endif
  //double vd    = 75.;  // drift velocity [um/ns]
  double vd    = 74.3;  // drift velocity [um/ns]

  TPC::GEM gem(sgprf,wpad,lpad,vgap,igap,gain,theta);

  double wzee  = vd*w0/1000.;// time bin width [mm]

  //--
  // Calculate position resolutions.
  //--
  TPC::Hit::Pulse::VGetTimeMethod *methodp = 0;
  if (isCOG) methodp = new TPC::Hit::Pulse::Cog(&pca);
  else       methodp = new TPC::Hit::Pulse::Inflection(&pca);

  TPC::Hit::Pulse::SetGetTimeMethodPtr(methodp);

  //int  npad = 0; // use pads in (-n,+n) for time calculation
  int  npad = 1; // use pads in (-n,+n) for time calculation
  //int  npad = 2; // use pads in (-n,+n) for time calculation
  //int  npad = 8; // use pads in (-n,+n) for time calculation
  //int  npad = 9999; // use pads in (-n,+n) for time calculation
  //if (isCOG) npad = 0;
  //if (isCOG) npad = 1;
  if (isCOG) npad = 3;
  //if (isCOG) npad = 4;
  //if (isCOG) npad = 9999;

  //--
  //  Open root file.
  //--
  stringstream fname;
  if (isCOG) fname << "signal.dray.cog";
  else       fname << "signal.dray.inf";
  fname << ".phi"  << setw(5) << setprecision(3) << setiosflags(ios::fixed) << phi
        << ".lam"  << setw(5) << setprecision(3) << setiosflags(ios::fixed) << lam
        << ".z"    << setw(3) << setprecision(0) << setiosflags(ios::fixed) 
                                                 << setfill('0')            << z0
        << ".nav"  << setw(4) << setprecision(1) << setiosflags(ios::fixed) << nav
        << ".sgpr" << setw(4) << setprecision(2) << setiosflags(ios::fixed) << sgprf
        << ".tbin" << setw(2) << setprecision(0) << setiosflags(ios::fixed) 
                                                 << setfill('0')            << w0
        << ".tpk"  << setw(3) << setprecision(0) << setiosflags(ios::fixed)
                                                 << setfill('0')            << tpk0
        << ".norm"  << setw(3) << setprecision(0) << setiosflags(ios::fixed)
                                                 << setfill('0')            << norm
        << ".nois" << setw(3) << setprecision(0) << setiosflags(ios::fixed)
                                                 << setfill('0')            << noise
        << ".noise"<< (TPC::Hit::Pulse::GetWithNoise() ? "On" : "Off")
        << ".sat"<< (TPC::Hit::Pulse::GetWithADCLimit() ? "On" : "Off")
        << ".root" << ends;
  TFile    *filep = new TFile(fname.str().data(),"RECREATE");
  filep->cd();

  //--
  // Define residual histograms.
  //--
  stringstream hname;
  hname << "hxcog" << ends;
  TH1D *hXcogp = new TH1D(hname.str().data(),"",100,-1.0,+1.0);
  TH1D &hXcog  = *hXcogp;

  hname.str("");
  hname.clear();
  hname << "hzcog" << ends;
  TH1D *hZcogp = new TH1D(hname.str().data(),"",200,-2.0,+2.0);
  TH1D &hZcog  = *hZcogp;

  //--
  // Loop over events.
  //--
  const int kNev = nev;
  for (int iev=0; iev<kNev; iev++) {
      double x0  = gRandom->Uniform(-wpad/2,+wpad/2);
      double y0  = 0.;
      double dz0 = gRandom->Uniform(-wzee/2,+wzee/2);  // time bin scan
      TPC::Track trk(phi,lam,x0,y0,z0+dz0,len,nav,vd); // create a track
      trk.Sort();                                      // sort cluster in y
      trk.Drift(z0);                                   // drift it to GEM
      TPC::Hit hit(trk, gem, pca);                     // create signals
      double xcog = hit.GetX() - x0;
      double zcog;
      if (isCOG) zcog = hit.GetZ(npad) - dz0 - 2.2; // shift due to asymmetry (cog)
      else       zcog = hit.GetZ(npad) - dz0 + 2.2; // shift due to asymmetry (inf)

      //cerr << "zcog=" << zcog << endl;
      
      hXcog.Fill(xcog);
      hZcog.Fill(zcog);
  }

  //--
  // Calculate resolutions.
  //--
#if 0
  // Use Gaussian fit
  hXcog.Fit("gaus","IN");
  double sgx  = hXcog.GetFunction("gaus")->GetParameter(2); // sigma
  double dsgx = hXcog.GetFunction("gaus")->GetParError(2);  // its error

  hZcog.Fit("gaus","IN");
  double sgz  = hZcog.GetFunction("gaus")->GetParameter(2); // sigma
  double dsgz = hZcog.GetFunction("gaus")->GetParError(2);  // its error
#else
  // Use RMS
  double sgx  = hXcog.GetRMS();
  double dsgx = hXcog.GetRMSError();

  double sgz  = hZcog.GetRMS();
  double dsgz = hZcog.GetRMSError();
#endif

  //--
  // Output residual data.
  //--
  ofstream fout("sg.dat",ios::app);
  fout << setw(5) << setprecision(3) << setiosflags(ios::fixed) << phi  << " "
       << setw(5) << setprecision(3) << setiosflags(ios::fixed) << lam  << " "
       << setw(4) << setprecision(0) << setiosflags(ios::fixed) << z0   << " "
       << setw(8) << setprecision(6) << setiosflags(ios::fixed) << sgx  << " "
       << setw(8) << setprecision(6) << setiosflags(ios::fixed) << dsgx << " "
       << setw(8) << setprecision(6) << setiosflags(ios::fixed) << sgz  << " "
       << setw(8) << setprecision(6) << setiosflags(ios::fixed) << dsgz
       << endl;

  cerr << setw(5) << setprecision(3) << setiosflags(ios::fixed) << phi  << " "
       << setw(5) << setprecision(3) << setiosflags(ios::fixed) << lam  << " "
       << setw(4) << setprecision(0) << setiosflags(ios::fixed) << z0   << " "
       << setw(8) << setprecision(6) << setiosflags(ios::fixed) << sgx  << " "
       << setw(8) << setprecision(6) << setiosflags(ios::fixed) << dsgx << " "
       << setw(8) << setprecision(6) << setiosflags(ios::fixed) << sgz  << " "
       << setw(8) << setprecision(6) << setiosflags(ios::fixed) << dsgz
       << endl;
#if 1
  //--
  // Draw residuals.
  //--
  stringstream cname;
  cname << "cresx" << ends;
  TCanvas *cp = new TCanvas(cname.str().data(),
    	                cname.str().data(),400.,400.);
  cp->cd();
  hXcog.Draw();

  cname.str("");
  cname.clear();
  cname << "cresz" << ends;
          cp = new TCanvas(cname.str().data(),
    	                cname.str().data(),400.,400.);
  cp->cd();
  hZcog.Draw();
#endif
  filep->Write();
  //TPC::Hit::ResetTup();
}
