// script to check the pulse shapes at two z positions.
// You need to create MC data by test1 or test2 before running this script.
// You also need to adjust the finle name of the MC file by changing 
// lastname and firstname vairables.
// You should run this in compile mode as:
//   $ root -l
//   [0] .L ShapeCheck.C+
//   [1] ShapeCheck();
//
#include "TSystem.h"
#include "TROOT.h"
#include "TMath.h"
#include "TFile.h"
#include "TNtupleD.h"
#include "TRandom.h"
#include "TCanvas.h"
#include "TH2D.h"
#include "TStyle.h"
#include "TEventList.h"

#include <fstream>
#include <sstream>
#include <iostream>
#include <iomanip>

#include "Signal.C"
#include "Pulse1.C"

void ShapeCheck(int z1 = 0, int z2 = 600)
{
    auto c1p = new TCanvas("c1", "c1",9,31,699,550);
    gStyle->SetOptStat(0);
    c1p->ToggleEventStatus();
    c1p->SetGridx();
    c1p->SetGridy();
    c1p->SetBorderSize(2);
    c1p->SetLeftMargin(0.1280576);
    c1p->SetBottomMargin(0.1343612);

    //const char *lastname  = "Results/true/inf/n1/noise50/signal.dray.inf.phi0.00.lam0.00.z";
    //const char *lastname  = "signal.dray.cog.phi0.00.lam0.00.z";
    //const char *firstname = ".nav38.0.sgpr0.27.tbin50.tpk120.nois050.root";
    const char *lastname  = "Results/4k.nofit.nav38.heed.prf270.2d.accurate_hnc/norm0.0061/signal.dray.cog.phi0.000.lam0.000.z";
    const char *firstname = ".nav37.9.sgpr0.27.tbin50.tpk120.nois001.root";

    stringstream infile;
    infile << lastname 
           << setw(3) << setfill('0') << z1
	   << firstname << ends;

    auto h1p = Signal(0,infile.str().data(),false);
    h1p->Draw();
    //h1p->ProfileX()->DrawCopy("same");
    h1p->ProfileX();
    auto h0_pfx = static_cast<TH1 *>(gROOT->FindObject("h0_pfx"));
    h0_pfx->SetLineColor(4);
    h0_pfx->SetLineWidth(2);
    h0_pfx->DrawCopy("same");
    //Pulse1(false,3.5e6)->DrawCopy("same");

    //--
    // 2nd plot
    //--
    auto c2p = new TCanvas("c2", "c2",9,31,699,550);
    c2p->ToggleEventStatus();
    c2p->SetGridx();
    c2p->SetGridy();
    c2p->SetBorderSize(2);
    c2p->SetLeftMargin(0.1280576);
    c2p->SetBottomMargin(0.1343612);

    infile.str("");
    infile.clear();
    infile << lastname 
           << setw(3) << setfill('0') << z2
	   << firstname << ends;
    auto h2p = Signal(1,infile.str().data(),false);
    h2p->Draw();
    //h2p->ProfileX()->DrawCopy("same");
    h2p->ProfileX();
    auto h1_pfx = static_cast<TH1 *>(gROOT->FindObject("h1_pfx"));
    h1_pfx->SetLineColor(4);
    h1_pfx->SetLineWidth(2);
    h1_pfx->DrawCopy("same");
    //Pulse1(false, 2.3e6)->DrawCopy("same");
}
