// script to plot ALTRO ADC signals for a given MC data set
// Output 2D histogram will be named "hn" where n is the value of the first argument.
// You need to create MC data by resol.sh or resolfil.sh before running this script.
//
TH2D *Signal(int n = 0, const char *fname = "tup.root", bool isg = true)
{
   auto fp = new TFile(fname);
   double ymax = 1000.;
   TCanvas *c1 = 0;
   if (isg) {
       c1 = new TCanvas("c1", "c1",9,31,699,550);
       gStyle->SetOptStat(0);
       c1->ToggleEventStatus();
       c1->SetGridx();
       c1->SetGridy();
       c1->SetBorderSize(2);
       c1->SetLeftMargin(0.1280576);
       c1->SetBottomMargin(0.1343612);
   }

   const double kW  = 50.; // time bin width [ns]
   const double off =  0.; // shift

   stringstream hname;
   hname << "h" << n << ends;
   auto  hp = new TH2D(hname.str().data(),"",11,-kW*1.5,9.5*kW,1000,0.,ymax);
   auto &h  = *hp;
   h.SetStats(0);
   h.Draw();
   h.GetXaxis()->SetTitle("drift time [ns]");
   h.GetXaxis()->SetLabelSize(0.05);
   h.GetXaxis()->SetTitleSize(0.06);
   h.GetYaxis()->SetTitle("Pulse Height");
   h.GetYaxis()->SetLabelSize(0.05);
   h.GetYaxis()->SetTitleSize(0.06);
   h.GetYaxis()->SetTitleOffset(1.0);

   TNtupleD *tup = static_cast<TNtupleD *>(gROOT->FindObject("tup"));
   stringstream cut;
   cut << "ksum<200" << ends;
   tup->Draw(">>elist",cut.str().data(),"goff");
   TEventList *elist = static_cast<TEventList *>(gROOT->FindObject("elist"));
   int nlist = elist->GetN();
   cerr << "Nhits = " << nlist << endl;

   for (int i=0; i<nlist; i++) {
       int event = elist->GetEntry(i);
       //cerr << "i=" << i << " event=" << event << endl;
       double am1;
       double a0;
       double a1;
       double a2;
       double a3;
       double a4;
       double a5;
       double a6;
       double a7;
       double a8;
       double a9;
       tup->SetBranchAddress("am1",&am1);
       tup->SetBranchAddress("a0",&a0);
       tup->SetBranchAddress("a1",&a1);
       tup->SetBranchAddress("a2",&a2);
       tup->SetBranchAddress("a3",&a3);
       tup->SetBranchAddress("a4",&a4);
       tup->SetBranchAddress("a5",&a5);
       tup->SetBranchAddress("a6",&a6);
       tup->SetBranchAddress("a7",&a7);
       tup->SetBranchAddress("a8",&a8);
       tup->SetBranchAddress("a9",&a9);

       tup->GetEntry(event);

       h.Fill((-1.+off)*kW,am1);
       h.Fill(( 0.+off)*kW,a0);
       h.Fill(( 1.+off)*kW,a1);
       h.Fill(( 2.+off)*kW,a2);
       h.Fill(( 3.+off)*kW,a3);
       h.Fill(( 4.+off)*kW,a4);
       h.Fill(( 5.+off)*kW,a5);
       h.Fill(( 6.+off)*kW,a6);
       h.Fill(( 7.+off)*kW,a7);
       h.Fill(( 8.+off)*kW,a8);
       h.Fill(( 9.+off)*kW,a9);
   }

   if (isg) h.Draw("same");
   return hp;
}
