#!/bin/sh
# ====================
#  resol_heed.bsub.sh
# ====================
#
# (Function)
#   Calculate resolutions for multiple drift lengths, etc.
# (Usage)
#   sh resol_heed.bsub.sh <maxevt> <datadir>
# (Upadate Record)
#   2020/09/01   K.Fujii         Derived from resol.sh
#
#--
#  Check arguments.
#--
if [ $# -ge 3 ]; then
      echo "Usage:"
      echo "  sh resol_heed.bsub.sh <maxevt> <datadir>"
      echo " where <maxevt> is the maximum number of events to analyaze"
      echo " per run with its default value being 10000"
      echo " <datadir> is the directory for Heed data with its default vale being \"Data\""
      exit 0
#--
# Set maximum number of events to reconstruct per run
#--
elif [ $# -ge 1 ]; then
      echo "maxevt is set to $1"
      maxevt=$1
      if [ $# -eq 2 ]; then
              echo "datadir is set to $2"
              datadir=$2
      fi
else
      maxevt=40000
      datadir=Data
fi
echo "----------------------------------------------------"
echo "$0: going to generate $maxevt events per data point"
echo "----------------------------------------------------"
#--
# Loop over data points
#--

iscog=true
#iscog=false

declare -a len=(0 2 5 10 15 20 30 40 50 60) # [cmm]
#declare -a len=(0 5 10 25 50 75 100 150 200 250)
#declare -a len=(0 10)
declare -i n=${#len[@]}
echo "resolutions for $n z points to be calculated:"

#que="-q s"
que=

test=
#check="echo"

list=`ls $datadir/edep.*.dlen000.00.root`
for file in $list; do
    for ((i=0;i<n;i++)); do
           l=${len[$i]}
           fi=`echo $file | sed -e 's;.*phi\([0-9.]\{1,\}\).*\.root;\1;'`
           th=`echo $file | sed -e 's;.*theta\([0-9.]\{1,\}\).*\.root;\1;'`
           cmd="root -l -b Resol_Heed.C+\\($l\,\\\\\\\"$file\\\\\\\"\,$maxevt\,$iscog\\) > /dev/null &"
           $check bsub $que -J "sgx:dlen$l.phi$fi.theta$th" -o run.dlen$l.phi$fi.theta$th.log "sh submit.sh \"$cmd\"" 
    done
done
echo "---------------------"
#--
# Wait for child processes to finish.
#--
wait
echo "---------------------"
echo "Calculation finished!"
#--
# That's it, folks!
#--
exit 0
