#!/bin/sh
# =============
#  resolfit.sh
# =============
#
# (Function)
#   Calculate resolutions for multiple drift lengths, etc.
# (Usage)
#   sh resolfit.sh <maxevt>
# (Upadate Record)
#   2020/04/16   K.Fujii         Original version.
#
#--
#  Check arguments.
#--
if [ $# -ge 2 ]; then
      echo "Usage:"
      echo "  sh resolfit.sh <maxevt>"
      echo " where <maxevt> is the maximum number of events to analyaze"
      echo " per run with its default value being 10000."
      exit 0
#--
# Set maximum number of events to reconstruct per run
#--
elif [ $# -eq 1 ]; then
      echo "maxevt is set to $1"
      maxevt=$1
else
      maxevt=4000
fi
echo "----------------------------------------------------"
echo "$0: going to generate $maxevt events per data point"
echo "----------------------------------------------------"
#--
# Loop over data points
#--
#phi=0.0   # phi angle        [rad]
#phi=0.1   # phi angle        [rad]
#phi=0.2   # phi angle        [rad]
#phi=0.3   # phi angle        [rad]
#
#phi=0.0 # [rad]
#phi=0.175 # [rad] = 10 [deg]
#phi=0.349 # [rad] = 20 [deg]
declare -a phi=(0.000 0.175 0.349)
declare -i m=${#phi[@]}
dphi=0.01 # phi angle spread [rad]

lam=0.0   # dip angle        [rad]
dlam=0.01 # dip angle spread [rad]

iscog=true
#iscog=false

declare -a len=(0 10 25 50 75 100 150 200 250 300 350 400 450 500 550 600)
declare -i n=${#len[@]}
echo "resolutions for $n z points to be calculated:"

#que="-q s"
que=

for ((i=0;i<n;i++)); do
    l=${len[$i]}
    for ((j=0;j<m;j++)); do
    fi=${phi[$j]}
        cmd="root -l -b ResolFit.C+\\($l\,$fi\,$dphi\,$lam\,$dlam\,$maxevt\,$iscog\\) >& /dev/null &"
        #eval $cmd
        eval "bsub $que -J \"sgx:dlen$l.phi$fi.$lam\" -o run.phi$fi.dlen$l.lam$lam.log \"sh submit.sh \\\"$cmd\\\"\" "
    done
done
echo "---------------------"
#--
# Wait for child processes to finish.
#--
wait
echo "---------------------"
echo "Calculation finished!"
#--
# That's it, folks!
#--
exit 0
